@@ -24,7 +24,7 @@ kuiper <- function(u, rads = FALSE, R = 1) {
     b2 <- 8 * Vn / ( 3 * f ) * m * (a1 - 3) * a2
     pvalue <- sum(b1 - b2)
   } else {
-    x <- matrix( runif(n * R, 0, 2 * pi), ncol = R)
+    x <- matrix( Rfast2::Runif(n * R, 0, 2 * pi), ncol = R)
     x <- Rfast::colSort(x) / (2 * pi)
     bvn <- f * ( Rfast::colMaxs(x - (i - 1)/n, value = TRUE) + Rfast::colMaxs(i/n - x, value = TRUE) )
     pvalue <- ( sum(bvn > Vn) + 1 ) / (R + 1)
